@@ -2,7 +2,7 @@
  * api.c - This file contains all of the API calls that are defined for
  *         external driver code to use.  
  * 
- *  $Id: api.c,v 1.162 2009/04/22 17:47:00 johns Exp $
+ *  $Id: api.c,v 1.163 2009/05/15 20:25:01 johns Exp $
  */
 
 #include "machine.h"
@@ -659,6 +659,9 @@ void apitextotex(apitexture * apitex, texture * tx) {
   tex->phong = 0.0;
   tex->phongexp = 0.0;
   tex->phongtype = 0;
+
+  tex->outline = 0.0;
+  tex->outlinewidth = 0.0;
 }
 
 void * rt_texture(SceneHandle sc, apitexture * apitex) {
@@ -711,6 +714,14 @@ void rt_tex_phong(void * voidtex, apiflt phong, apiflt phongexp, int type) {
   tex->phongtype = type;
 }
 
+
+void rt_tex_outline(void * voidtex, apiflt outline, apiflt outlinewidth) {
+  texture * tex = (texture *) voidtex;
+  tex->outline = outline;
+  tex->outlinewidth = outlinewidth;
+}
+
+
 static void add_bounded_object(scenedef * scene, object * obj) {
   object * objtemp;
 
